( cd opt/kde/share/doc/HTML/pt_BR/kgeo ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kgeo ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kppp ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kppp ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/katomic ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/katomic ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kbounce ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/khelpcenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kdm ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kdm ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/smb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/smb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/spellchecking ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/spellchecking ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/bell ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/bell ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/arts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/arts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keys ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keys ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/powerctrl ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kalarmd ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cookies ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filetypes ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filetypes ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/desktop ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cache ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/cache ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/clock ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/clock ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/email ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/email ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/fonts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/fonts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/icons ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/icons ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/khtml ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/khtml ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filemanager ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/filemanager ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/mouse ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/mouse ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panel ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/panel ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/proxy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/proxy ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kmixcfg ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kmixcfg ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/passwords ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/passwords ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/ebrowsing ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/ebrowsing ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/background ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/background ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmaccess ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmaccess ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/colors ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/colors ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/crypto ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/crypto ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/energy ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/energy ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmstyle ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmstyle ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/netpref ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/netpref ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlaunch ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlaunch ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmktalkd ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmktalkd ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmcss ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmcss ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/laptop ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/laptop ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmnotify ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmnotify ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmsmserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmsmserver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/screensaver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/screensaver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/windowmanagement ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/windowmanagement ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kwindecoration ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kwindecoration ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmkonsole ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmkonsole ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/language ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/language ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/useragent ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/useragent ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatcrit ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatcrit ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatwarn ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmlowbatwarn ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keyboard ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/keyboard ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmtaskbar ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmtaskbar ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kthememgr ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kthememgr ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmfontinst ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kcontrol/kcmfontinst ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker-applets ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kicker-applets ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/konq-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/konq-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/keduca ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/keduca ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kstars ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kstars ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/quanta ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/quanta ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/dma ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pci ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pci ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/usb ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/usb ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/nics ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/nics ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/scsi ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/scsi ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/interrupts ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/interrupts ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/devices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/devices ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/blockdevices ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/blockdevices ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/xserver ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/xserver ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/samba ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/samba ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/sound ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/sound ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/partitions ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/partitions ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/memory ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/memory ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pcmcia ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/pcmcia ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/processor ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/processor ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/ioports ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/ioports ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/protocols ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kinfocenter/protocols ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
( cd opt/kde/share/doc/HTML/pt_BR/kate-plugins ; rm -rf common )
( cd opt/kde/share/doc/HTML/pt_BR/kate-plugins ; ln -sf /opt/kde/share/doc/HTML/pt_BR/common common )
